@@ -1,13 +1,13 @@
 package Complete::Program;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.37'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.38'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Complete::Setting;
+use Complete::Common qw(:all);
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -46,9 +46,6 @@ sub complete_program {
 
     my %args = @_;
     my $word     = $args{word} // "";
-    my $ci       = $args{ci} // $Complete::Setting::OPT_CI;
-    my $fuzzy    = $args{fuzzy} // $Complete::Setting::OPT_FUZZY;
-    my $map_case = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
 
     my @dirs = split(($^O =~ /Win32/ ? qr/;/ : qr/:/), $ENV{PATH});
     my @all_progs;
@@ -61,7 +58,6 @@ sub complete_program {
 
     Complete::Util::complete_array_elem(
         word => $word, array => \@all_progs,
-        ci=>$ci, fuzzy=>$fuzzy, map_case=>$map_case,
     );
 }
 
@@ -80,7 +76,7 @@ Complete::Program - Completion routines related to program names
 
 =head1 VERSION
 
-This document describes version 0.37 of Complete::Program (from Perl distribution Complete-Program), released on 2015-09-17.
+This document describes version 0.38 of Complete::Program (from Perl distribution Complete-Program), released on 2015-11-29.
 
 =head1 DESCRIPTION
 
@@ -93,6 +89,8 @@ Complete program name found in PATH.
 
 Windows is supported, on Windows PATH will be split using /;/ instead of /:/.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
